<?php
namespace App\Http\Middleware;

use Closure;
use Exception;
use Firebase\JWT\JWT;
use Firebase\JWT\ExpiredException;

class JwtMiddleware
{
  public function handle($request, Closure $next, $guard = null)
  {
    $token = str_replace('Bearer ', '', $request->headers->get('Authorization'));

    if (!$token) {
      return response()->json([
        'error' => 'Token not provided.'
      ], 401);
    }
    try {
      $content = JWT::decode($token, env('JWT_SECRET'), ['HS256']);
    } catch (ExpiredException $e) {
      return response()->json([
        'error' => 'Provided token is expired.'
      ], 400);
    } catch (Exception $e) {
      echo $e;
      return response()->json([
        'error' => 'An error while decoding token.'
      ], 400);
    }

    // Make sciper, data & permissions accessible through request
    $request->attributes->add(['user_sciper' => $content->sub]);
    $request->attributes->add(['user_data' => $content->tequila_data]);
    $request->attributes->add(['user_permissions' => $content->permissions]);
    $request->attributes->add(['user_role' => $content->role]);

    return $next($request);
  }
}