-- MySQL Script generated by MySQL Workbench
-- Thu Apr 18 09:44:04 2019
-- Model: New Model    Version: 1.0
-- MySQL Workbench Forward Engineering

-- -----------------------------------------------------
-- Schema mydb
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Schema canap_db
-- -----------------------------------------------------
DROP SCHEMA IF EXISTS `canap_db` ;

-- -----------------------------------------------------
-- Schema canap_db
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `canap_db` DEFAULT CHARACTER SET utf8 ;
USE `canap_db` ;

-- -----------------------------------------------------
-- Table `canap_db`.`responsible`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`responsible` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`responsible` (
  `responsible_id` INT(11) NOT NULL AUTO_INCREMENT,
  `responsible_gender` VARCHAR(10) NULL DEFAULT NULL,
  `responsible_name` VARCHAR(200) NULL DEFAULT NULL,
  `responsible_fsname` VARCHAR(200) NULL DEFAULT NULL,
  `responsible_street` VARCHAR(100) NULL DEFAULT NULL,
  `responsible_npa` VARCHAR(100) NULL DEFAULT NULL,
  `responsible_phone` VARCHAR(20) NULL DEFAULT NULL,
  PRIMARY KEY (`responsible_id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `canap_db`.`status`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`status` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`status` (
  `status_value` VARCHAR(30) NOT NULL,
  PRIMARY KEY (`status_value`),
  UNIQUE INDEX `value_UNIQUE` (`status_value` ASC))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `canap_db`.`location`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`location` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`location` (
  `location_id` INT NOT NULL AUTO_INCREMENT,
  `location_site` VARCHAR(100) NOT NULL,
  PRIMARY KEY (`location_id`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `canap_db`.`job`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`job` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`job` (
  `job_id` INT NOT NULL AUTO_INCREMENT,
  `job_short_value` VARCHAR(45) NOT NULL,
  `job_full_value` VARCHAR(100) NOT NULL,
  PRIMARY KEY (`job_id`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `canap_db`.`position`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`position` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`position` (
  `position_id` INT NOT NULL AUTO_INCREMENT,
  `position_access_group` VARCHAR(300) NOT NULL,
  `position_spot_number` INT NOT NULL DEFAULT 0,
  `fk_location` INT NOT NULL,
  `fk_job` INT NOT NULL,
  PRIMARY KEY (`position_id`),
  INDEX `fk_position_location1_idx` (`fk_location` ASC),
  INDEX `fk_position_job1_idx` (`fk_job` ASC),
  CONSTRAINT `fk_position_location1`
    FOREIGN KEY (`fk_location`)
    REFERENCES `canap_db`.`location` (`location_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_position_job1`
    FOREIGN KEY (`fk_job`)
    REFERENCES `canap_db`.`job` (`job_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `canap_db`.`applicant`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`applicant` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`applicant` (
  `applicant_id` INT(11) NOT NULL AUTO_INCREMENT,
  `applicant_guest_sciper` VARCHAR(100) NOT NULL,
  `applicant_maturity` TINYINT(4) NOT NULL,
  `applicant_gender` VARCHAR(10) NOT NULL,
  `applicant_name` VARCHAR(200) NOT NULL,
  `applicant_fsname` VARCHAR(200) NOT NULL,
  `applicant_address_street` VARCHAR(200) NOT NULL,
  `applicant_address_npa` VARCHAR(200) NOT NULL,
  `applicant_home_phone` VARCHAR(200) NOT NULL,
  `applicant_personal_phone` VARCHAR(200) NOT NULL,
  `applicant_mail` VARCHAR(200) NOT NULL,
  `applicant_birthdate` VARCHAR(45) NOT NULL,
  `applicant_origin` VARCHAR(100) NOT NULL,
  `applicant_nationality` VARCHAR(100) NOT NULL,
  `applicant_foreign_authorization` VARCHAR(10) NULL DEFAULT NULL,
  `applicant_avs` VARCHAR(45) NOT NULL,
  `applicant_main_language` VARCHAR(100) NOT NULL,
  `applicant_speaks_french` TINYINT(4) NOT NULL,
  `applicant_speaks_german` TINYINT(4) NOT NULL,
  `applicant_speaks_english` TINYINT(4) NOT NULL,
  `applicant_speaks_other` TINYINT(4) NOT NULL,
  `applicant_has_majority` TINYINT(4) NOT NULL,
  `applicant_scolarity_end` VARCHAR(45) NOT NULL,
  `applicant_already_applicant` TINYINT(4) NOT NULL,
  `applicant_already_applicant_year` VARCHAR(45) NULL DEFAULT NULL,
  `applicant_application_date` DATETIME NOT NULL,
  `applicant_application_updated_date` DATETIME NULL DEFAULT NULL,
  `fk_applicant_main_responsible` INT(11) NULL DEFAULT NULL,
  `fk_applicant_sec_responsible` INT(11) NULL DEFAULT NULL,
  `fk_status` VARCHAR(30) NOT NULL,
  `fk_position` INT NOT NULL,
  PRIMARY KEY (`applicant_id`),
  INDEX `fk_applicant_responsible_idx` (`fk_applicant_main_responsible` ASC),
  INDEX `fk_applicant_responsible1_idx` (`fk_applicant_sec_responsible` ASC),
  INDEX `fk_applicant_status1_idx` (`fk_status` ASC),
  INDEX `fk_applicant_position1_idx` (`fk_position` ASC),
  CONSTRAINT `fk_applicant_responsible`
    FOREIGN KEY (`fk_applicant_main_responsible`)
    REFERENCES `canap_db`.`responsible` (`responsible_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_applicant_responsible1`
    FOREIGN KEY (`fk_applicant_sec_responsible`)
    REFERENCES `canap_db`.`responsible` (`responsible_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_applicant_status1`
    FOREIGN KEY (`fk_status`)
    REFERENCES `canap_db`.`status` (`status_value`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_applicant_position1`
    FOREIGN KEY (`fk_position`)
    REFERENCES `canap_db`.`position` (`position_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `canap_db`.`comment`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`comment` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`comment` (
  `comment_id` INT(11) NOT NULL AUTO_INCREMENT,
  `comment_owner_sciper` VARCHAR(45) NOT NULL,
  `comment_content` VARCHAR(1000) NOT NULL,
  `comment_is_private` TINYINT(4) NOT NULL,
  `comment_date` DATETIME NOT NULL,
  `fk_applicant_id` INT(11) NOT NULL,
  PRIMARY KEY (`comment_id`),
  INDEX `fk_comment_applicant1_idx` (`fk_applicant_id` ASC),
  CONSTRAINT `fk_comment_applicant1`
    FOREIGN KEY (`fk_applicant_id`)
    REFERENCES `canap_db`.`applicant` (`applicant_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `canap_db`.`file`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`file` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`file` (
  `file_id` INT(11) NOT NULL AUTO_INCREMENT,
  `file_name` VARCHAR(200) NOT NULL,
  `file_path` VARCHAR(500) NOT NULL,
  `fk_applicant_id` INT(11) NOT NULL,
  PRIMARY KEY (`file_id`),
  INDEX `fk_file_applicant1_idx` (`fk_applicant_id` ASC),
  CONSTRAINT `fk_file_applicant1`
    FOREIGN KEY (`fk_applicant_id`)
    REFERENCES `canap_db`.`applicant` (`applicant_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `canap_db`.`marker`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`marker` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`marker` (
  `marker_id` INT(11) NOT NULL AUTO_INCREMENT,
  `marker_owner_sciper` VARCHAR(45) NOT NULL,
  `marker_value` INT NOT NULL,
  `fk_applicant_id` INT(11) NOT NULL,
  PRIMARY KEY (`marker_id`),
  INDEX `fk_marker_applicant1_idx` (`fk_applicant_id` ASC),
  CONSTRAINT `fk_marker_applicant1`
    FOREIGN KEY (`fk_applicant_id`)
    REFERENCES `canap_db`.`applicant` (`applicant_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `canap_db`.`professional_activity`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`professional_activity` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`professional_activity` (
  `professional_activity_id` INT(11) NOT NULL AUTO_INCREMENT,
  `professional_activity_company` VARCHAR(100) NULL DEFAULT NULL,
  `professional_activity_location` VARCHAR(200) NULL DEFAULT NULL,
  `professional_activity_activity` VARCHAR(100) NULL DEFAULT NULL,
  `professional_activity_years` VARCHAR(50) NULL DEFAULT NULL,
  `fk_applicant_id` INT(11) NOT NULL,
  PRIMARY KEY (`professional_activity_id`),
  INDEX `fk_professional_activity_applicant1_idx` (`fk_applicant_id` ASC),
  CONSTRAINT `fk_professional_activity_applicant1`
    FOREIGN KEY (`fk_applicant_id`)
    REFERENCES `canap_db`.`applicant` (`applicant_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `canap_db`.`scolarity`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`scolarity` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`scolarity` (
  `scolarity_id` INT(11) NOT NULL AUTO_INCREMENT,
  `scolarity_school` VARCHAR(200) NULL DEFAULT NULL,
  `scolarity_location` VARCHAR(200) NULL DEFAULT NULL,
  `scolarity_level` VARCHAR(100) NULL DEFAULT NULL,
  `scolarity_years` VARCHAR(100) NULL DEFAULT NULL,
  `fk_applicant_id` INT(11) NOT NULL,
  PRIMARY KEY (`scolarity_id`),
  INDEX `fk_scolarity_applicant1_idx` (`fk_applicant_id` ASC),
  CONSTRAINT `fk_scolarity_applicant1`
    FOREIGN KEY (`fk_applicant_id`)
    REFERENCES `canap_db`.`applicant` (`applicant_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `canap_db`.`training`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `canap_db`.`training` ;

CREATE TABLE IF NOT EXISTS `canap_db`.`training` (
  `training_id` INT(11) NOT NULL AUTO_INCREMENT,
  `training_job` VARCHAR(100) NULL DEFAULT NULL,
  `training_company` VARCHAR(100) NULL DEFAULT NULL,
  `fk_applicant_id` INT(11) NOT NULL,
  PRIMARY KEY (`training_id`),
  INDEX `fk_training_applicant1_idx` (`fk_applicant_id` ASC),
  CONSTRAINT `fk_training_applicant1`
    FOREIGN KEY (`fk_applicant_id`)
    REFERENCES `canap_db`.`applicant` (`applicant_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;
